#import "MSDelegateViewController.h"

@interface MSDelegateViewController () <MRMapViewDelegate>
@property (nonatomic, strong) MRMapView *mapView;
@property (nonatomic, strong) MRDirections *directions;
@end

@implementation MSDelegateViewController

- (id)initWithNibName:(NSString *)name bundle:(NSBundle *)bundle {
    if ((self = [super initWithNibName:name bundle:bundle])) {
        self.edgesForExtendedLayout = UIRectEdgeNone;
        
        UIBarButtonItem *button1 = [[UIBarButtonItem alloc] initWithTitle:@"Directions" style:UIBarButtonItemStylePlain target:self action:@selector(directionsAction)];
        self.navigationItem.rightBarButtonItems = @[button1];
    }
    return self;
}

#pragma mark - UIViewController

- (void)loadView {
    self.mapView = [[MRMapView alloc] init];
    self.mapView.delegate = self;
    self.mapView.mapKey = [MREditorKey keyForMap:MAP_ID app:APP_ID];
    self.view = self.mapView;
}

#pragma mark - MSExampleViewController

+ (NSString *)exampleTitle {
    return @"Map Delegates";
}

+ (NSString *)exampleInfo {
    return @"Map that logs delegate callbacks.\n\n"
    @"• All MRMapViewDelegate methods are logged to console.\n"
    @"• A button to start and stop directions.\n";
}

#pragma mark - MRMapViewDelegate
- (void)mapPickerDidPickMap:(nonnull MRMap *)map {
    self.mapView.mapKey = map.key;
    NSLog(@"%s", __PRETTY_FUNCTION__);
}

- (nonnull UIViewController *)viewControllerToAddSheetToForMapView:(MRMapView *)mapView {
    NSLog(@"%s", __PRETTY_FUNCTION__);
    return self;
}

- (void)mapViewWillStartLoadingMap:(MRMapView *)mapView {
    NSLog(@"%s", __FUNCTION__);
}

- (void)mapViewDidFinishLoadingMap:(MRMapView *)mapView {
    NSLog(@"%s", __FUNCTION__);
}

- (void)mapViewDidFailLoadingMap:(MRMapView *)mapView withError:(NSError *)error {
    NSLog(@"%s - error:%@", __FUNCTION__, error);
}

- (void)mapViewDidChangeUseAccessiblePaths:(MRMapView *)mapView {
    NSLog(@"%s", __FUNCTION__);
}

- (void)mapView:(MRMapView *)mapView willScrollToStepAtIndex:(NSUInteger)index {
    NSLog(@"%s - index:%@", __FUNCTION__, @(index));
}

- (void)mapView:(MRMapView *)mapView visibleMapRectDidChange:(BOOL)animated {
    NSLog(@"%s - animated:%@", __FUNCTION__, @(animated));
}

- (MRAnnotationView *)mapView:(MRMapView *)mapView viewForAnnotation:(id<MRAnnotation>)annotation {
    NSLog(@"%s - annotation:%p", __FUNCTION__, annotation);
    if ([annotation isKindOfClass:[MRPlacemark class]]) {
        MRPlacemarkAnnotationView *defaultView = (MRPlacemarkAnnotationView *)[mapView defaultViewForAnnotation:annotation];
        defaultView.canTapCallout = YES;
        return defaultView;
    }
    return nil;
}

- (void)mapView:(MRMapView *)mapView didAddAnnotationViews:(NSArray *)views {
    NSLog(@"%s - views:%@", __FUNCTION__, @(views.count));
}

- (void)mapView:(MRMapView *)mapView didLoadPlacemarks:(NSArray *)placemarks {
    NSLog(@"%s - placemarks:%@", __FUNCTION__, @(placemarks.count));
}

- (void)mapView:(MRMapView *)mapView didSelectAnnotationView:(MRAnnotationView *)view {
    NSLog(@"%s - view:%p", __FUNCTION__, view);
}

- (void)mapView:(MRMapView *)mapView didDeselectAnnotationView:(MRAnnotationView *)view {
    NSLog(@"%s - view:%p", __FUNCTION__, view);
}

- (void)mapView:(MRMapView *)mapView didTapCalloutForAnnotationView:(MRAnnotationView *)view {
    NSLog(@"%s - view:%p", __FUNCTION__, view);
}

#pragma mark - Action

- (void)directionsAction {
    if (!self.mapView.route) {
        MRDirectionsRequest *request = [[MRDirectionsRequest alloc] init];
        request.app = self.mapView.mapKey.parent;
        request.destination = [MRDirectionsDestination destinationWithPlacemarkKey:((MRPlacemark *)self.mapView.placemarks[0]).key];
        request.source = [MRDirectionsSource sourceWithPlacemarkKey:((MRPlacemark *)self.mapView.placemarks[1]).key];
        
        __weak typeof(self) weakSelf = self;
        self.directions = [[MRDirections alloc] initWithRequest:request presentingViewController:self];
        [self.directions calculateDirectionsWithCompletionHandler:^(MRDirectionsResponse *response, NSError *error) {
            [weakSelf directionsResponseDidLoad:response error:error];
        }];
    } else {
        self.mapView.route = nil;
    }
}

#pragma mark - Internal

- (void)directionsResponseDidLoad:(MRDirectionsResponse *)response error:(NSError *)error {
    self.directions = nil;
    if (!error && response.routes.count > 0) {
        MRRoute *route = response.routes.firstObject;
        [self.mapView deselectAnnotationAnimated:NO];
        [self.mapView setRoute:route animated:YES];
    } else {
        UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"Could not load directions" message:error.localizedDescription preferredStyle:UIAlertControllerStyleAlert];
        UIAlertAction *action = [UIAlertAction actionWithTitle:@"Ok" style:UIAlertActionStyleDefault handler:nil];
        [alertController addAction:action];
        [self presentViewController:alertController animated:YES completion:nil];
    }
}


@end
