#import "MSExampleDetailViewController.h"
#import "MSExampleViewController.h"

#define REUSE_ID        @"a"

@interface MSExampleDetailViewController () <UITableViewDelegate, UITableViewDataSource>
@property (nonatomic, strong) Class exampleClass;
@property (nonatomic, strong) UITableView *tableView;
@end

@implementation MSExampleDetailViewController

- (id)initWithExampleClass:(Class)class {
    if ((self = [super init])) {
        self.exampleClass = class;
        self.title = [class exampleTitle];
    }
    return self;
}

#pragma mark - UIViewController

- (void)viewWillAppear:(BOOL)animated {
    [super viewWillAppear:animated];
    for (NSIndexPath *i in [self.tableView indexPathsForSelectedRows]) {
        [self.tableView deselectRowAtIndexPath:i animated:animated];
    }
}

- (void)loadView {
    UIView *view = [[UIView alloc] init];
    [self setView:view];
    
    self.tableView = [[UITableView alloc] initWithFrame:view.bounds style:UITableViewStyleGrouped];
    self.tableView.autoresizingMask = UIViewAutoresizingFlexibleWidth|UIViewAutoresizingFlexibleHeight;
    self.tableView.delegate = self;
    self.tableView.dataSource = self;
    [self.tableView registerClass:[UITableViewCell class] forCellReuseIdentifier:REUSE_ID];
    [self.view addSubview:self.tableView];
}

#pragma mark - UITableViewDelegate

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath {
    UIViewController *vc = [[self.exampleClass alloc] init];
    [[self navigationController] pushViewController:vc animated:YES];
}

#pragma mark - UITableViewDataSource

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:REUSE_ID forIndexPath:indexPath];
    cell.textLabel.text = [self.exampleClass exampleTitle];
    cell.textLabel.font = [UIFont systemFontOfSize:25];
    cell.accessoryType = UITableViewCellAccessoryDisclosureIndicator;
    return cell;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    return 1;
}

- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath {
    return 60;
}

- (NSString *)tableView:(UITableView *)tableView titleForFooterInSection:(NSInteger)section {
    return [self.exampleClass exampleInfo];
}

@end
