#import "MSManualRoutingViewController.h"

@interface MSManualRoutingViewController ()
@property (nonatomic, strong) MRMapView *mapView;
@property (nonatomic, strong) MRDirections *directions;
@end

@implementation MSManualRoutingViewController

- (id)initWithNibName:(NSString *)name bundle:(NSBundle *)bundle {
    if ((self = [super initWithNibName:name bundle:bundle])) {
        self.edgesForExtendedLayout = UIRectEdgeNone;
        
        UIBarButtonItem *button = [[UIBarButtonItem alloc] initWithTitle:@"Directions" style:UIBarButtonItemStylePlain target:self action:@selector(directionsAction)];
        self.navigationItem.rightBarButtonItems = @[button];
    }
    return self;
}


#pragma mark - UIViewController

- (void)loadView {
    self.mapView = [[MRMapView alloc] init];
    self.mapView.showsUserLocation = YES;
    self.mapView.mapKey = [MREditorKey keyForMap:MAP_ID app:APP_ID];
    self.view = self.mapView;
}

#pragma mark - MSExampleViewController

+ (NSString *)exampleTitle {
    return @"Manual Routing";
}

+ (NSString *)exampleInfo {
    return @"Example of how to do manual routing.\n\n"
    @"• `Directions` button to start and stop directions from the selected placemark.\n"
    @"• Manual routing by disabling `showsUserLocation` when directions are enabled.\n";
}

#pragma mark - Action

- (void)directionsAction {
    if (!self.mapView.route && self.mapView.selectedAnnotation) {
        MRDirectionsRequest *request = [[MRDirectionsRequest alloc] init];
        request.app = self.mapView.mapKey.parent;
        request.destination = [MRDirectionsDestination destinationWithPlacemarkKey:((MRPlacemark *)self.mapView.selectedAnnotation).key];
        request.source = [MRDirectionsSource sourceWithCurrentLocation];
        
        __weak typeof(self) weakSelf = self;
        self.directions = [[MRDirections alloc] initWithRequest:request presentingViewController:self];
        [self.directions calculateDirectionsWithCompletionHandler:^(MRDirectionsResponse *response, NSError *error) {
            [weakSelf directionsResponseDidLoad:response error:error];
        }];
    } else {
        [self.directions cancel];
        self.directions = nil;
        [self.mapView setRoute:nil animated:YES];
        self.mapView.showsUserLocation = YES;
    }
}

#pragma mark - Internal

- (void)directionsResponseDidLoad:(MRDirectionsResponse *)response error:(NSError *)error {
    self.directions = nil;
    if (!error && response.routes.count > 0) {
        MRRoute *route = response.routes.firstObject;
        [self.mapView deselectAnnotationAnimated:NO];
        [self.mapView setRoute:route animated:YES];
        self.mapView.showsUserLocation = NO;
    } else {
        UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"Could not load directions" message:error.localizedDescription preferredStyle:UIAlertControllerStyleAlert];
        UIAlertAction *action = [UIAlertAction actionWithTitle:@"Ok" style:UIAlertActionStyleDefault handler:nil];
        [alertController addAction:action];
        [self presentViewController:alertController animated:YES completion:nil];
    }
}

@end
