#import "MSVisibleMapRectViewController.h"

@interface MSVisibleMapRectViewController () <MRMapViewDelegate>
@property (nonatomic, strong) MRMapView *mapView;
@end

@implementation MSVisibleMapRectViewController

- (id)initWithNibName:(NSString *)name bundle:(NSBundle *)bundle {
    if ((self = [super initWithNibName:name bundle:bundle])) {
        self.edgesForExtendedLayout = UIRectEdgeNone;
        
        UIBarButtonItem *button1 = [[UIBarButtonItem alloc] initWithTitle:@"Zoom" style:UIBarButtonItemStylePlain target:self action:@selector(zoomAction)];
        UIBarButtonItem *button2 = [[UIBarButtonItem alloc] initWithTitle:@"Overview" style:UIBarButtonItemStylePlain target:self action:@selector(overviewAction)];
        self.navigationItem.rightBarButtonItems = @[button1, button2];
    }
    return self;
}

#pragma mark - UIViewController

- (void)loadView {
    self.mapView = [[MRMapView alloc] init];
    self.mapView.delegate = self;
    self.mapView.mapKey = [MREditorKey keyForMap:MAP_ID app:APP_ID];
    self.view = self.mapView;
}

#pragma mark - MSExampleViewController

+ (NSString *)exampleTitle {
    return @"Zoom and Rotation";
}

+ (NSString *)exampleInfo {
    return @"Example of how to programatically change the visible map rect.\n\n"
    @"• Map starts zoomed to the upper left corner.\n"
    @"• Button to show the full map.\n"
    @"• Button to zoom onto the 'Widu' placemark.\n";
}

#pragma mark - MRMapViewDelegate

- (void)mapViewDidFinishLoadingMap:(MRMapView *)mapView {
    [self.mapView setVisibleMapRect:CGRectMake(100, 100, 100, 100) animated:NO completion:NULL];
}

- (void)mapPickerDidPickMap:(nonnull MRMap *)map {
    self.mapView.mapKey = map.key;
}

- (nonnull UIViewController *)viewControllerToAddSheetToForMapView:(MRMapView *)mapView {
    return self;
}

#pragma mark - Action

- (void)zoomAction {
    for (id<MRAnnotation> i in self.mapView.placemarks) {
        if ([i.title isEqual:@"Widu"]) {
            CGFloat width = 15 * self.mapView.map.unitsPerMeter;
            [self.mapView setVisibleMapRect:CGRectMake(i.point.x - width/2, i.point.y - width/2, width, width) rotationAngle:M_PI/4 animated:YES completion:NULL];
        }
    }
}

- (void)overviewAction {
    MRMap *map = self.mapView.map;
    [self.mapView setVisibleMapRect:CGRectMake(0, 0, map.size.width, map.size.height) animated:YES completion:NULL];
}

@end
