//
//  MSAddAnnotationViewController.swift
//  MeridianSwiftSamples
//
//  Created by Stephen Kelly on 5/19/17.
//  Copyright © 2017 Aruba Networks. All rights reserved.
//

import UIKit

class MSAddAnnotationViewController: UIViewController, MSExampleViewController, MRMapViewDelegate {
    private lazy var mapView: MRMapView = {
        let mapView = MRMapView()
        mapView.delegate = self
        mapView.mapKey = MREditorKey(forMap:MAP_ID, app:APP_ID)
        return mapView
    }()

    private lazy var userAnnotation: MRPointAnnotation = {
        let userAnnotation = MRPointAnnotation()
        userAnnotation.point = CGPoint(x:872, y:420)
        return userAnnotation
    }()

    private lazy var userAnnotation2: MRPointAnnotation = {
        let userAnnotation2 = MRPointAnnotation()
        userAnnotation2.point = CGPoint(x:150, y:100)
        return userAnnotation2
    }()

    override func viewDidLoad() {
        super.viewDidLoad()
        self.view = self.mapView
        self.mapView.addAnnotation(self.userAnnotation)
        self.mapView.addAnnotation(self.userAnnotation2)

        let button0 = UIBarButtonItem(title: "Toggle", style: .plain, target: self, action: #selector(self.toggleAnnotation))
        self.navigationItem.rightBarButtonItems = [button0]
    }

    // MARK: - MSExampleViewController

    static func exampleTitle() -> String {
        return "Add Annotation"
    }

    static func exampleDetail() -> String {
        return "Example of how to add custom annotations.\n\n" +
            "• Custom annotation with a smiley image and `Hello There` in the callout.\n" +
            "• Button to add/remove a second smiley annotation.\n"
    }

    // MARK: - MRMapViewDelegate
    
    func mapPickerDidPick(_ map: MRMap) {
        self.mapView.mapKey = map.key
    }
    
    func viewControllerToAddSheetTo(for mapView: MRMapView) -> UIViewController {
        return self
    }

    func mapView(_ mapView: MRMapView, viewFor annotation: MRAnnotation?) -> MRAnnotationView? {
        guard let thisAnnotation = annotation as? MRPointAnnotation else {
            return nil
        }
        if thisAnnotation == self.userAnnotation || thisAnnotation == self.userAnnotation2 {
            if let annotationView = self.mapView.dequeueReusableAnnotationView(withIdentifier: "a") {
                return annotationView
            }
            let smileyView = UIImageView(image: #imageLiteral(resourceName: "Smiley"))
            smileyView.isUserInteractionEnabled = true

            let label = UILabel()
            label.text = "Hello There!"
            label.font = UIFont(name: "Papyrus", size: 20)
            label.sizeToFit()
            label.frame = CGRect(origin: CGPoint(x: 2, y: 4), size: label.frame.size)

            let container = UIView(frame: label.bounds)
            container.addSubview(label)

            let annotationView = MRAnnotationView.init(annotation: userAnnotation, reuseIdentifier: "a")
            annotationView.frame = smileyView.bounds
            annotationView.canShowCallout = true
            annotationView.leftCalloutAccessoryView = container
            annotationView.addSubview(smileyView)
            return annotationView
        }
        return nil
    }

    // MARK: - Action

    @objc private func toggleAnnotation() {
        if self.mapView.annotations.contains(where: { $0 === self.userAnnotation2 }) {
           self.mapView.removeAnnotation(self.userAnnotation2)
        } else {
            self.mapView.addAnnotation(self.userAnnotation2)
        }
    }
}
