//
//  MSManualRoutingViewController.swift
//  MeridianSwiftSamples
//
//  Created by Stephen Kelly on 5/22/17.
//  Copyright © 2017 Aruba Networks. All rights reserved.
//

import UIKit

class MSManualRoutingViewController: UIViewController, MRMapViewDelegate, MSExampleViewController {
    private lazy var mapView: MRMapView = {
        let mapView = MRMapView()
        mapView.delegate = self
        mapView.mapKey = MREditorKey(forMap:MAP_ID, app:APP_ID)
        return mapView
    }()

    var directions: MRDirections?

    override func viewDidLoad() {
        super.viewDidLoad()
        self.view = self.mapView

        let button0 = UIBarButtonItem(title: "Directions", style: .plain, target: self, action: #selector(self.directionsAction))
        self.navigationItem.rightBarButtonItems = [button0]
    }
    
    // MARK: - MRMapViewDelegate
    
    func mapPickerDidPick(_ map: MRMap) {
        self.mapView.mapKey = map.key
    }
    
    func viewControllerToAddSheetTo(for mapView: MRMapView) -> UIViewController {
        return self
    }

    // MARK: - MSExampleViewController

    static func exampleTitle() -> String {
        return "Manual Routing"
    }

    static func exampleDetail() -> String {
        return "Example of how to do manual routing.\n\n" +
            "• `Directions` button to start and stop directions from the selected placemark.\n" +
            "• Manual routing by disabling `showsUserLocation` when directions are enabled.\n"
    }

    // MARK: - Actions

    @objc private func directionsAction() {
        if self.mapView.route != nil {
            self.directions?.cancel()
            self.directions = nil
            self.mapView.setRoute(nil, animated:true)
            self.mapView.showsUserLocation = true
            return
        }

        guard let appKey = self.mapView.mapKey.parent else {
            return
        }
        guard let destinationAnnotation = self.mapView.selectedAnnotation as? MRPlacemark else {
            return
        }
        let request = MRDirectionsRequest()
        request.app = appKey
        request.destination = MRDirectionsDestination(placemarkKey: destinationAnnotation.key)
        request.source = MRDirectionsSource.withCurrentLocation()
        self.directions = MRDirections(request: request, presenting: self)
        self.directions?.calculate(completionHandler: { [weak self] (response, error) in
            self?.directionsResponseDidLoad(response: response, error: error)
        })
    }

    // MARK: - Internal

    private func directionsResponseDidLoad(response: MRDirectionsResponse?, error: Error?) {
        self.directions = nil
        if let routeResponse = response?.routes, error == nil, routeResponse.count > 0 {
            self.mapView.deselectAnnotation(animated: false)
            self.mapView.setRoute(routeResponse[0], animated: true)
            self.mapView.showsUserLocation = false
            return
        }

        // Error or no routes:
        let alertController = UIAlertController(title: "Could not load directions", message: error?.localizedDescription, preferredStyle: .alert)
        let OKAction = UIAlertAction(title: "OK", style: .default)
        alertController.addAction(OKAction)
        self.present(alertController, animated: true)
    }
}
