//
//  MSOverlayViewController.swift
//  MeridianSwiftSamples
//
//  Created by Stephen Kelly on 5/22/17.
//  Copyright © 2017 Aruba Networks. All rights reserved.
//

import UIKit

class MSOverlayViewController: UIViewController, MRMapViewDelegate, MSExampleViewController {
    private lazy var mapView: MRMapView = {
        let mapView = MRMapView()
        mapView.delegate = self
        mapView.mapKey = MREditorKey(forMap:MAP_ID, app:APP_ID)
        return mapView
    }()

    private var pathOverlay: MRPathOverlay?

    override func viewDidLoad() {
        super.viewDidLoad()
        self.view = self.mapView

        let button0 = UIBarButtonItem(title: "Toggle Overlay", style: .plain, target: self, action: #selector(self.toggleOverlay))
        self.navigationItem.rightBarButtonItems = [button0]
    }

    // MARK: - MSExampleViewController

    static func exampleTitle() -> String {
        return "Custom Overlays"
    }

    static func exampleDetail() -> String {
        return "Example of how to add custom overlays.\n\n" +
            "• Button to toggle the appearance of a circular green overlay.\n"
    }

    // MARK: - MRMapViewDelegate
    
    func mapPickerDidPick(_ map: MRMap) {
        self.mapView.mapKey = map.key
    }
    
    func viewControllerToAddSheetTo(for mapView: MRMapView) -> UIViewController {
        return self
    }
    
    func mapView(_ mapView: MRMapView, rendererFor overlay: MRPathOverlay) -> MRPathRenderer {
        let renderer = MRPathRenderer(overlay: overlay)
        renderer.strokeColor = UIColor(red:0.000, green:0.478, blue:1.000, alpha:1)
        renderer.fillColor = UIColor(red:0.000, green:0.478, blue:1.000, alpha:0.4)
        renderer.lineWidth = 20
        renderer.lineCap = .round
        renderer.lineJoin = .bevel
        return renderer
    }

    func mapView(_ mapView: MRMapView, didAddOverlayRenderers renderers: [MRPathRenderer]) {
        // noop
    }

    // MARK: - Internal

    @objc private func toggleOverlay() {
        if let overlay = pathOverlay {
            self.mapView.remove(overlay)
            self.pathOverlay = nil
        } else {
            self.pathOverlay = MRPathOverlay(circleOfCenter: CGPoint(x: 200, y: 200), radius: 50)
            self.mapView.add(self.pathOverlay!)
        }
    }
}
