//
//  MSSelectAnnotationViewController.swift
//  MeridianSwiftSamples
//
//  Created by Stephen Kelly on 5/19/17.
//  Copyright © 2017 Aruba Networks. All rights reserved.
//

import UIKit

class MSSelectAnnotationViewController: UIViewController, MRMapViewDelegate, MSExampleViewController {
    private lazy var mapView: MRMapView = {
        let mapView = MRMapView()
        mapView.delegate = self
        mapView.mapKey = MREditorKey(forMap:MAP_ID, app:APP_ID)
        return mapView
    }()

    private var selectedOnLoad = false

    override func viewDidLoad() {
        super.viewDidLoad()
        self.view = self.mapView

        let button0 = UIBarButtonItem(title: "Select", style: .plain, target: self, action: #selector(self.selectAnnotation))
        let button1 = UIBarButtonItem(title: "Deselect", style: .plain, target: self, action: #selector(self.deselectAnnotation))
        self.navigationItem.rightBarButtonItems = [button0, button1]
    }

    // MARK: - MSExampleViewController

    static func exampleTitle() -> String {
        return "Select Annotation"
    }

    static func exampleDetail() -> String {
        return "Example of how to programatically select annotations.\n\n" +
            "• `Converse` annotation starts initially selected.\n" +
            "• Button to select/deselect the `Gant` annotation.\n"
    }

    // MARK: - MRMapViewDelegate
    
    func mapPickerDidPick(_ map: MRMap) {
        self.mapView.mapKey = map.key
    }
    
    func viewControllerToAddSheetTo(for mapView: MRMapView) -> UIViewController {
        return self
    }
    
    func mapView(_ mapView: MRMapView, didAdd views: [MRAnnotationView]) {
        if self.selectedOnLoad {
            return
        }
        for view in views {
            if let title = view.annotation.title, title == "Converse" {
                self.mapView.selectAnnotation(view.annotation, animated: true)
                self.selectedOnLoad = true
            }
        }
    }

    // MARK: - Action

    @objc private func selectAnnotation() {
        for placemark in self.mapView.placemarks {
            if let title = placemark.title, title == "Gant" {
                self.mapView.selectAnnotation(placemark, animated: true)
                break
            }
        }
    }

    @objc private func deselectAnnotation() {
        self.mapView.deselectAnnotation(animated: true)
    }
}
